@@ -147,7 +147,6 @@ class ApiList(View):
                 if vm:
                     datarec.update(vm)
                     resp = json_response(datarec)
-                    resp['Clear-Site-Data'] = '"cache", "storage"'
                     return resp
                 return json_response(datarec)
 
@@ -217,7 +216,6 @@ class ApiList(View):
             if vm:
                 kw.update(vm)
                 resp = json_response(kw)
-                resp['Clear-Site-Data'] = '"cache", "storage"'
                 return resp
             return json_response(kw)
 
@@ -545,7 +543,11 @@ class DashboardItem(View):
             html = ''.join(item.render(ar))
         else:
             html = ""
-        ar.success(html=html)
+        kw = dict(html=html)
+        vm = test_version_mismatch(request)
+        if vm:
+            kw.update(vm)
+        ar.success(**kw)
         return json_response(ar.response, ar.content_type)
 
 
@@ -643,10 +645,15 @@ class Index(View):
             context = ar.get_printable_context(**context)
             env = settings.SITE.plugins.jinja.renderer.jinja_env
             template = env.get_template("react/main.html")
-            return http.HttpResponse(
+            resp = http.HttpResponse(
                 template.render(**context),
                 content_type='text/html;charset="utf-8"')
 
+            if 'update_found' in request.GET:
+                resp['Clear-Site-Data'] = '"cache", "storage"'
+
+            return resp
+
         return with_user_profile(user.user_type, getit)
 
 
